CradminSelectableListItem | django_cradmin API Document

    import CradminSelectableListItem from 'django_cradmin/scripts/django_cradmin/components/CradminSelectableListItem.jsx'

public class | source

# CradminSelectableListItem

#### Extends:

react~React.Component → CradminSelectableListItem

## Static Member Summary

Static Public Members
public static get | defaultProps: * |

## Constructor Summary

Public Constructor
public | constructor(props: *) |

## Member Summary

Public Members
public get | ariaTitle: * |
public get | fullClassName: * |
public get | hotKeysHandlers: * |
public get | hotKeysMap: * |

## Method Summary

Public Methods
public | componentWillUnmount() |
public | getTabIndex(): string |
public | handleBlur() |
public | handleFocus() |
public | handleSelect(event: *) |
public | initializeSignalHandlers() |
public | render(): * |
public | renderContent(): * |
public | renderContentModeHtml(): * |
public | renderContentModeTitleAndDescription(): * |
public | renderContentModeTitleOnly(): * |
public | renderDescription(): string |
public | renderIcon(): string |
public | renderIconWrapper(): string |
public | renderTitle(): * |
public | renderWrapper(): * |

## Static Public Members

### public static get defaultProps: * source

## Public Constructors

### public constructor(props: *) source

#### Params:

Name | Type | Attribute | Description
props | * |  |

## Public Members

### public get ariaTitle: * source

### public get fullClassName: * source

### public get hotKeysHandlers: * source

### public get hotKeysMap: * source

## Public Methods

### public componentWillUnmount() source

### public getTabIndex(): string source

#### Return:

string

### public handleBlur() source

### public handleFocus() source

### public handleSelect(event: *) source

#### Params:

Name | Type | Attribute | Description
event | * |  |

### public initializeSignalHandlers() source

### public render(): * source

#### Return:

*

### public renderContent(): * source

#### Return:

*

### public renderContentModeHtml(): * source

#### Return:

*

### public renderContentModeTitleAndDescription(): * source

#### Return:

*

### public renderContentModeTitleOnly(): * source

#### Return:

*

### public renderDescription(): string source

#### Return:

string

### public renderIcon(): string source

#### Return:

string

### public renderIconWrapper(): string source

#### Return:

string

### public renderTitle(): * source

#### Return:

*

### public renderWrapper(): * source

#### Return:

*